// "Extended Blochowicz function"
// formula (4) in Nakanishi, Griffin, Mamontov, Sokolov J Chem Phys 2012

// gcc -o ~/bin/blochowicz-extended -lm blochowicz-extended.c

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <complex.h>

#define K 99
#define Nmax 10000
#define SQR(x) ((x)*(x))


double fct( double x, double Atot, double Aa, double tf, double ta, double c,
            double b, double g, double d, double nu )
{
    return -Atot * cimag( Aa*cpow( 1+cpow(I*x*ta/c,b), g-d )/
                          cpow( 1+cpow(I*x*ta,b), g ) -
                          cpow( I*x*tf, nu ) );
        
}


int main( int argc, char **argv )
{
    double Atot, Aa, tf, ta, c, b, g, d, nu, x, y;
    int nf, i;
    const int mpar = 9;

    // Read parameters.
    if ( argc-1 != mpar ){
        fprintf( stderr, "blochowicz-extended Atot Aa tf ta c b g d nu\n" );
        exit(1);
    }
    Atot           = atof( argv[ 1] );
    Aa             = atof( argv[ 2] );
    tf             = atof( argv[ 3] );
    ta             = atof( argv[ 4] );
    c              = atof( argv[ 5] );
    b              = atof( argv[ 6] );
    g              = atof( argv[ 7] );
    d              = atof( argv[ 8] );
    nu             = atof( argv[ 9] );

    // Read input points, compute function, write output data pairs.
    if( scanf( "%i", &nf )!=1 ){
        fprintf( stderr, "number of output points not found\n" );
        exit(1);
    }
    for( i=0; i<nf; ++i ){
        if( scanf( "%lg", &x )!=1 ){
            fprintf( stderr, "point %i not found\n", i );
            exit(1);
        }
        y = fct( x, Atot, Aa, tf, ta, c, b, g, d, nu );
        printf( "%g %g\n", x, y );
    }
}
