//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  fstring.cpp
//! \brief Collection of string functions.

#include "defs.hpp"

#include "commands.hpp"
#include "fregistry.hpp"
#include "func.hpp"


//**************************************************************************************************
//*  Functions of one argument
//**************************************************************************************************

void func_cmd(string s) { frida_command(s); } // TO CHECK: -> "eval" ? right approach ?

int func_len(string s) { return s.size(); }


//**************************************************************************************************
//*  Functions of two arguments
//**************************************************************************************************

string func_mul(string s, int n)
{
    string ret = s;
    for (int i = 1; i < n; ++i)
        ret += s;
    return ret;
}


//**************************************************************************************************
//*  Registration
//**************************************************************************************************

//! Registers string functions.

void fstring_initialize()
{
    auto G = SFuncRegistry::instance();
    CFuncMetadata m;

    // operators by precedence (which should agree with xax_yacc.ypp):
    m = { "*", 2, "a*b     [product]", 6 }; // TODO: copying this line from fbase is weird
    G->register_fct_s_si(m, func_mul);

    // f( 1 arg )
    m = { "cmd", 1, "(s): execute s as Frida command" };
    G->register_fct_0_s(m, func_cmd);
    m = { "len", 1, "(s): length of string s" };
    G->register_fct_i_s(m, func_len);
}
