//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  dualplot.hpp
//! \brief Declares class CPlot.

#include <map>
#include <memory>
#include "axis.hpp"

//! One plot frame.

class CPlot
{
public:
    CPlot(int _iPlot, bool _logx, bool _logy, bool _p2D, bool _logz);
    CPlot(int _iPlot, bool _logx, bool _logy) : CPlot(_iPlot, _logx, _logy, false, false) {}
    CPlot(int _iPlot) : CPlot(_iPlot, false, false) {}
    CPlot(CPlot const&) = delete;
    CPlot& operator=(CPlot const&) = delete;

    int iPlot; //!< The index of this frame in NPloWin::Plots.
    bool p2D; //!< Two-dimensional color plot?
    CAxis X; //!< Limits, log flag &c for x axis.
    CAxis Y; //!< Limits, log flag &c for y axis.
    CAxis Z; //!< Limits, log flag &c for z axis in 2D plot.
    // For data plotting:
    int maxpoints; //!< Maximum # points to be plotted without reduction.
    bool with_errors; //!< Plot error bars?
    // For curve plotting:
    int equipoints; //!< Start curve plot with this # grid points.
    bool refine; //!< Refine curve plot when appropriate?

    void gp_write(const std::string& in);
    void start_frame1D(
        const std::string& caller, const std::string& xlabel, const std::string& ylabel);
    void start_frame2D(const std::string& caller);
    void close_frame2D(
        const std::string& xlabel, const std::string& zlabel, const std::string& ylabel);
    void add_spec(
        bool as_line, bool new_slice, int style_no, const std::vector<double>& xp,
        const std::vector<double>& yp, const std::vector<double>& dyp,
        const std::vector<std::string>& zentries, const std::string& xco, const std::string& yco,
        const std::string& info);
    void ps_line(const std::string& line);
    void show_specs();
    void doc_TxLine(const std::string& line);
    void doc_PtTxLine(const std::string& line, int num);
    void doc_CvTxLine(const std::string& line, int num);
    void write_postscript(
        const std::string& fname, const std::string& mode, const bool withDefs,
        std::map<const std::string, std::string>&& settings);
    void set_aux(const std::string& cmd);
    std::string info() const;

private:
    std::shared_ptr<class CGnuPlotter> gnuPlotter;
    std::shared_ptr<class CPS_Plotter> ps_Plotter;
};
